/*************************************************************************
 *	This code is written by N. Kehtarnavaz and N. Kim as part of the 
 *	textbook "Real-Time Digital Signal Processing Based on TMS320C6000".
 *************************************************************************/

#define CHIP_6713 1

#include <stdio.h>
#include <c6x.h>
#include <csl.h>
#include <csl_mcbsp.h>
#include <csl_irq.h>
#include <math.h>

#include "dsk6713.h"
#include "dsk6713_aic23.h"

#define SCALE 	1000

interrupt void transmit_ISR(void);

DSK6713_AIC23_CodecHandle hCodec;
DSK6713_AIC23_Config config = DSK6713_AIC23_DEFAULTCONFIG; // Codec configuration with default settings

float sine_array[8] = { /* Fill the array elements */ };

main()
{
	DSK6713_init();		// Initialize the board support library, must be called first
	hCodec = DSK6713_AIC23_openCodec(0, &config);

	MCBSP_FSETS(SPCR1, RINTM, FRM);
	MCBSP_FSETS(SPCR1, XINTM, FRM);
	MCBSP_FSETS(RCR1, RWDLEN1, 32BIT);
	MCBSP_FSETS(XCR1, XWDLEN1, 32BIT);
	
	DSK6713_AIC23_setFreq(hCodec, DSK6713_AIC23_FREQ_8KHZ);
	
	IRQ_globalDisable();			// Globally disables interrupts
	IRQ_nmiEnable();				// Enables the NMI interrupt
	IRQ_map(IRQ_EVT_XINT1,15);		// Maps an event to a physical interrupt number
	IRQ_enable(IRQ_EVT_XINT1);		// Enables the event
	IRQ_globalEnable();				// Globally enables interrupts

	while(1)
	{	
	}
}

interrupt void transmit_ISR(void)
{
	int temp;
 	
 	/* Modify this function to generate sinewave continuosly */
 	
	temp = (short) ( sine_array[ ] * SCALE );
	
	
	MCBSP_write(DSK6713_AIC23_DATAHANDLE, temp << 16 );
}
